package com.example.producer;

import avro.Product;
import avro.ProductKey;
import com.example.controller.Controller;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.stream.messaging.Processor;
import org.springframework.kafka.support.KafkaHeaders;
import org.springframework.messaging.Message;
import org.springframework.messaging.support.MessageBuilder;
import org.springframework.stereotype.Service;

@Service
public class Producer {
    private static final Logger LOGGER = LoggerFactory.getLogger(Producer.class);

    @Autowired
    private Processor processor;

    public void produceProductDetails(Product product) {

        // creating partition key for kafka topic
        ProductKey productKey = new ProductKey();
        productKey.setId(product.getId());
        productKey.setCategoryId(product.getCategoryId());
        Message<Product> message = MessageBuilder.withPayload(product)
                .setHeader(KafkaHeaders.MESSAGE_KEY, productKey)
                .build();

        LOGGER.info("Sending Product data with key {} and value as {}",productKey.toString(),product.toString());

        processor.output().send(message);
    }

}